@@ -1,4 +1,5 @@
 import os
+from pathlib import Path
 
 from dotenv import load_dotenv
 
@@ -6,3 +7,5 @@ load_dotenv()
 
 OPENAI_API_KEY = os.environ.get("OPENAI_API_KEY", None)
 VERBOSE = int(os.environ.get("CDG_VERBOSE", "0"))
+
+MODULE_PATH = str(Path(__file__).parent)  # To load internal data
